/*
  This file is part of Cuber.

    Cuber is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Cuber is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Cuber.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.dvlcube.cuber.factory;

/**
 * Creates random names.
 * 
 * @author wonka
 */
public class NameFactory {

	public static final int CONSONANTS = 0;

	public static final int VOWELS = 1;

	public static int getRandomNumbers(int amount) {
		return (int) (Math.random() * amount);
	}

	private final String[] consonantBridges = { "bl;br", "cc;ck;ch;cl;cr", "dl;dh;dr;dw", "fl;fr", "gh;gl;gr", "hl;hr",
			"kl;kr;kn;ks;ky", "ll;lh;lly", "pl;pr;ph", "qu", "rr;rh", "sl;sp;ss;sw;st;sy", "tl;tr;ts;th;tw", "ul",
			"vl", "wr;wh" };
	private final String[] letters = { "bcdfghjklmnprstvwyz", "aeiou" };
	private String name;
	private int nameLength;
	// private final String[] initialBridges = {"bj", "mc"};
	// private final String[] neverInitials = {"tt", "rr"};
	private final StringBuilder names = new StringBuilder();

	/**
	 * Creates a random name.
	 */
	public NameFactory() {
		setNameLength();
		setRandomName();
	}

	/**
	 * Creates the specified number of random names.
	 * 
	 * @param names
	 *            The desired number of random names.
	 */
	public NameFactory(int names) {
		for (int i = 0; i < names; i++) {
			setNameLength();
			setRandomName();
		}
	}

	/* Helpers */
	public String getBridge() {
		String randomBridge = consonantBridges[(int) (Math.random() * consonantBridges.length)];
		String[] bridgeItems = randomBridge.split(";");
		int randomItem = (int) (Math.random() * bridgeItems.length);
		String bridge = bridgeItems[randomItem];
		return bridge;
	}

	public String getCompleteName() {
		return names.toString().replaceFirst(" ", "");
	}

	public String[] getConsonantBridges() {
		return consonantBridges;
	}

	public String getConsonants() {
		return letters[0];
	}

	public int getConsonantsLength() {
		return letters[0].length();
	}

	public int getLength(int kind) {
		return letters[kind].length();
	}

	public String[] getLetters() {
		return letters;
	}

	/**
	 * Gets the last created name.
	 * 
	 * @return The last name generated by this instance.
	 */
	public String getName() {
		return name;
	}

	public int getNameLength() {
		return nameLength;
	}

	public String getVowels() {
		return letters[1];
	}

	public int getVowelsLength() {
		return letters[1].length();
	}

	public String initCap(String string) {
		String initialLetter = string.substring(0, 1);
		String newString = initialLetter.toUpperCase() + string.substring(1);
		return newString;
	}

	public char newConsonant() {
		return getConsonants().charAt((int) (Math.random() * getConsonantsLength()));
	}

	public char newVowel() {
		return getVowels().charAt((int) (Math.random() * getVowelsLength()));
	}

	public final void setNameLength() {
		nameLength = (int) (Math.random() * 4) + 3;
		if (nameLength % 2 == 1) {
			nameLength++;
		}
	}

	/**
	 * Builds a random name with an initial upper case letter.
	 */
	public final void setRandomName() {
		StringBuilder nameBuilder = new StringBuilder();
		for (int i = getRandomNumbers(2); i < getNameLength(); i++) {
			if (i % 2 == 0) {
				if (getRandomNumbers(10) < 4) {
					nameBuilder.append(getBridge());
				} else {
					nameBuilder.append(newConsonant());
				}
			} else {
				nameBuilder.append(newVowel());
			}
		}
		name = initCap(nameBuilder.toString());
		names.append(" ").append(name);
	}

	/**
	 * Builds a random name with an initial upper case letter.
	 * 
	 * @return
	 */
	public void setRandomName2() {
		StringBuilder nameBuilder = new StringBuilder();

		for (int i = 0; i < getNameLength(); i++) {
			nameBuilder.append(letters[i % 2].charAt((int) (Math.random() * getLength(i % 2))));
		}
		name = initCap(nameBuilder.toString());
	}
}
